#! /bin/bash

trap "echo '*** BUILD FAILED! ***' 1>&2" ERR
set -ex -o pipefail
umask 022
export PATH='/bin:/usr/bin:/usr/local/bin:~/diet-pc/tools'
export CFLAGS=${CFLAGS:--Os}
export CXXFLAGS=${CXXFLAGS:--Os}

rebuild () {
    tar xjf irqbalance-0.56.tar.bz2
    cd irqbalance-0.56
    bunzip2 -c ../irqbalance-0.55-dietpc-patch.bz2 | patch -p1 -b
    ed -s Makefile.am >/dev/null <<EOF
1,\$s/-g -O[2s] //
w
q
EOF
    ./autogen.sh
    ./configure --prefix=/usr
    make
    gcc -o irqbalance *.o -Wl,-Bstatic -lglib -Wl,-Bdynamic
    strip -R .note -R .comment irqbalance
    mkdir -p ../irqbalance/sbin
    cp irqbalance ../irqbalance/sbin/
    cd ..
    rm -rf irqbalance-0.56
}

while read FN; do
    eval "[ -e $FN ] || rebuild"
done < MANIFEST

ARCH=`ipkg -V 0 print_architecture | tail -n 1 | cut -f2 -d' '`
for CTRLFILE in */CONTROL/control; do
    sed -i -e "s/__ARCH__/$ARCH/g" $CTRLFILE
    sudo ipkg-build -o root -g root `dirname $CTRLFILE`/..
done
